Crate fh101rf

Crate fh101rf 

Driver crate for the FH101RF Wake-Up Radio

The driver is built on top of embedded-hal, which means it is portable and can be used on any platform that implements the embedded-hal API (also async)

Modules

registers
FH101RF Registers.

Structs

Fh101rf
Fh101rfConfig
LcoCalibData

Enums

Error
Errors that can occur when using the FH101RF